CentredAxes
===========

.. currentmodule:: stonerplots

.. autoclass:: CentredAxes
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CentredAxes.__call__

   .. rubric:: Methods Documentation

   .. automethod:: __call__
